/*
lkmonitor (Linux Kernel Monitor)

Application for monitoring and tuning a Linux kernel.

Copyright (C) 2005,2006  Fernando Apesteguía

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <bonobo.h>
#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

static GnomeUIInfo menu3_uiinfo[] =
{
  GNOMEUIINFO_MENU_EXIT_ITEM (on_quit1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo menu4_uiinfo[] =
{
  GNOMEUIINFO_MENU_ABOUT_ITEM (on_about1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo menubar1_uiinfo[] =
{
  GNOMEUIINFO_MENU_FILE_TREE (menu3_uiinfo),
  GNOMEUIINFO_MENU_HELP_TREE (menu4_uiinfo),
  GNOMEUIINFO_END
};

GtkWidget*
create_window1 (void)
{
  GtkWidget *window1;
  GdkPixbuf *window1_icon_pixbuf;
  GtkWidget *vbox1;
  GtkWidget *menubar1;
  GtkWidget *nb_main;
  GtkWidget *fixed8;
  GtkWidget *image4;
  GtkWidget *lbl_processor;
  GtkWidget *lbl_vendor;
  GtkWidget *lbl_family;
  GtkWidget *lbl_model;
  GtkWidget *lbl_stepping;
  GtkWidget *lbl_Mhz;
  GtkWidget *lbl_cache;
  GtkWidget *lbl_fpu;
  GtkWidget *lbl_fpu_exception;
  GtkWidget *lbl_cpu_id_level;
  GtkWidget *lbl_wp;
  GtkWidget *lbl_bogomips;
  GtkWidget *scrolledwindow2;
  GtkWidget *viewport2;
  GtkWidget *lbl_flags;
  GtkWidget *label183;
  GtkWidget *label184;
  GtkWidget *label158;
  GtkWidget *lbl_model_name;
  GtkWidget *label162;
  GtkWidget *label160;
  GtkWidget *label163;
  GtkWidget *label164;
  GtkWidget *label165;
  GtkWidget *label166;
  GtkWidget *label167;
  GtkWidget *label168;
  GtkWidget *label178;
  GtkWidget *label176;
  GtkWidget *label159;
  GtkWidget *label186;
  GtkWidget *fixed9;
  GtkWidget *frame2;
  GtkWidget *fixed10;
  GtkWidget *pb_mem;
  GtkWidget *pb_swap;
  GtkWidget *label187;
  GtkWidget *image5;
  GtkWidget *lbl_total;
  GtkWidget *lbl_free;
  GtkWidget *lbl_buffers;
  GtkWidget *lbl_cached;
  GtkWidget *lbl_active;
  GtkWidget *lbl_inactive;
  GtkWidget *lbl_dirty;
  GtkWidget *lbl_hp_free;
  GtkWidget *lbl_hp_size;
  GtkWidget *lbl_high_total;
  GtkWidget *lbl_high_free;
  GtkWidget *lbl_low_total;
  GtkWidget *lbl_low_free;
  GtkWidget *lbl_swap_total;
  GtkWidget *lbl_swap_free;
  GtkWidget *label220;
  GtkWidget *label218;
  GtkWidget *label188;
  GtkWidget *label189;
  GtkWidget *label190;
  GtkWidget *lbl_swap_cached;
  GtkWidget *label191;
  GtkWidget *label192;
  GtkWidget *label193;
  GtkWidget *lbl_hp_total;
  GtkWidget *label194;
  GtkWidget *label195;
  GtkWidget *label196;
  GtkWidget *label211;
  GtkWidget *label197;
  GtkWidget *label198;
  GtkWidget *label199;
  GtkWidget *label200;
  GtkWidget *label201;
  GtkWidget *label222;

  window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_size_request (window1, 560, 437);
  gtk_window_set_title (GTK_WINDOW (window1), _("lkmonitor"));
  gtk_window_set_position (GTK_WINDOW (window1), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (window1), 462, 342);
  gtk_window_set_resizable (GTK_WINDOW (window1), FALSE);
  window1_icon_pixbuf = create_pixbuf ("lkmonitor/lkm-logo.png");
  if (window1_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (window1), window1_icon_pixbuf);
      gdk_pixbuf_unref (window1_icon_pixbuf);
    }

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (window1), vbox1);

  menubar1 = gtk_menu_bar_new ();
  gtk_widget_show (menubar1);
  gtk_box_pack_start (GTK_BOX (vbox1), menubar1, FALSE, FALSE, 0);
  gnome_app_fill_menu (GTK_MENU_SHELL (menubar1), menubar1_uiinfo,
                       NULL, FALSE, 0);

  nb_main = gtk_notebook_new ();
  gtk_widget_show (nb_main);
  gtk_box_pack_start (GTK_BOX (vbox1), nb_main, TRUE, TRUE, 0);
  gtk_widget_set_size_request (nb_main, -1, 360);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (nb_main), GTK_POS_LEFT);

  fixed8 = gtk_fixed_new ();
  gtk_widget_show (fixed8);
  gtk_container_add (GTK_CONTAINER (nb_main), fixed8);
  gtk_widget_set_size_request (fixed8, -1, 320);

  image4 = create_pixmap (window1, "lkmonitor/gnome-cpu.png");
  gtk_widget_show (image4);
  gtk_fixed_put (GTK_FIXED (fixed8), image4, 408, 32);
  gtk_widget_set_size_request (image4, 40, 40);

  lbl_processor = gtk_label_new ("");
  gtk_widget_show (lbl_processor);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_processor, 135, 20);
  gtk_widget_set_size_request (lbl_processor, 144, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_processor), TRUE);

  lbl_vendor = gtk_label_new ("");
  gtk_widget_show (lbl_vendor);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_vendor, 135, 40);
  gtk_widget_set_size_request (lbl_vendor, 160, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_vendor), TRUE);

  lbl_family = gtk_label_new ("");
  gtk_widget_show (lbl_family);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_family, 135, 64);
  gtk_widget_set_size_request (lbl_family, 104, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_family), TRUE);

  lbl_model = gtk_label_new ("");
  gtk_widget_show (lbl_model);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_model, 135, 80);
  gtk_widget_set_size_request (lbl_model, 264, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_model), TRUE);

  lbl_stepping = gtk_label_new ("");
  gtk_widget_show (lbl_stepping);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_stepping, 135, 120);
  gtk_widget_set_size_request (lbl_stepping, 41, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_stepping), TRUE);

  lbl_Mhz = gtk_label_new ("");
  gtk_widget_show (lbl_Mhz);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_Mhz, 135, 140);
  gtk_widget_set_size_request (lbl_Mhz, 64, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_Mhz), TRUE);

  lbl_cache = gtk_label_new ("");
  gtk_widget_show (lbl_cache);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_cache, 135, 160);
  gtk_widget_set_size_request (lbl_cache, 56, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_cache), TRUE);

  lbl_fpu = gtk_label_new ("");
  gtk_widget_show (lbl_fpu);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_fpu, 135, 180);
  gtk_widget_set_size_request (lbl_fpu, 41, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_fpu), TRUE);

  lbl_fpu_exception = gtk_label_new ("");
  gtk_widget_show (lbl_fpu_exception);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_fpu_exception, 135, 200);
  gtk_widget_set_size_request (lbl_fpu_exception, 41, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_fpu_exception), TRUE);

  lbl_cpu_id_level = gtk_label_new ("");
  gtk_widget_show (lbl_cpu_id_level);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_cpu_id_level, 135, 220);
  gtk_widget_set_size_request (lbl_cpu_id_level, 41, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_cpu_id_level), TRUE);

  lbl_wp = gtk_label_new ("");
  gtk_widget_show (lbl_wp);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_wp, 135, 240);
  gtk_widget_set_size_request (lbl_wp, 41, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_wp), TRUE);

  lbl_bogomips = gtk_label_new ("");
  gtk_widget_show (lbl_bogomips);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_bogomips, 135, 260);
  gtk_widget_set_size_request (lbl_bogomips, 72, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_bogomips), TRUE);

  scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow2);
  gtk_fixed_put (GTK_FIXED (fixed8), scrolledwindow2, 135, 280);
  gtk_widget_set_size_request (scrolledwindow2, 274, 40);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_POLICY_ALWAYS, GTK_POLICY_NEVER);

  viewport2 = gtk_viewport_new (NULL, NULL);
  gtk_widget_show (viewport2);
  gtk_container_add (GTK_CONTAINER (scrolledwindow2), viewport2);

  lbl_flags = gtk_label_new ("");
  gtk_widget_show (lbl_flags);
  gtk_container_add (GTK_CONTAINER (viewport2), lbl_flags);
  gtk_widget_set_size_request (lbl_flags, -1, 15);

  label183 = gtk_label_new (_("Processor"));
  gtk_widget_show (label183);
  gtk_fixed_put (GTK_FIXED (fixed8), label183, 16, 20);
  gtk_widget_set_size_request (label183, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label183), TRUE);

  label184 = gtk_label_new (_("Vendor"));
  gtk_widget_show (label184);
  gtk_fixed_put (GTK_FIXED (fixed8), label184, 16, 40);
  gtk_widget_set_size_request (label184, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label184), TRUE);

  label158 = gtk_label_new (_("Family"));
  gtk_widget_show (label158);
  gtk_fixed_put (GTK_FIXED (fixed8), label158, 16, 60);
  gtk_widget_set_size_request (label158, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label158), TRUE);

  lbl_model_name = gtk_label_new ("");
  gtk_widget_show (lbl_model_name);
  gtk_fixed_put (GTK_FIXED (fixed8), lbl_model_name, 135, 100);
  gtk_widget_set_size_request (lbl_model_name, 176, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_model_name), TRUE);

  label162 = gtk_label_new (_("Stepping"));
  gtk_widget_show (label162);
  gtk_fixed_put (GTK_FIXED (fixed8), label162, 16, 120);
  gtk_widget_set_size_request (label162, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label162), TRUE);

  label160 = gtk_label_new (_("Model name"));
  gtk_widget_show (label160);
  gtk_fixed_put (GTK_FIXED (fixed8), label160, 16, 100);
  gtk_widget_set_size_request (label160, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label160), TRUE);

  label163 = gtk_label_new (_("Mhz"));
  gtk_widget_show (label163);
  gtk_fixed_put (GTK_FIXED (fixed8), label163, 16, 140);
  gtk_widget_set_size_request (label163, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label163), TRUE);

  label164 = gtk_label_new (_("Cache"));
  gtk_widget_show (label164);
  gtk_fixed_put (GTK_FIXED (fixed8), label164, 16, 160);
  gtk_widget_set_size_request (label164, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label164), TRUE);

  label165 = gtk_label_new (_("fpu"));
  gtk_widget_show (label165);
  gtk_fixed_put (GTK_FIXED (fixed8), label165, 16, 180);
  gtk_widget_set_size_request (label165, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label165), TRUE);

  label166 = gtk_label_new (_("fpu exception"));
  gtk_widget_show (label166);
  gtk_fixed_put (GTK_FIXED (fixed8), label166, 16, 200);
  gtk_widget_set_size_request (label166, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label166), TRUE);

  label167 = gtk_label_new (_("Cpu id level"));
  gtk_widget_show (label167);
  gtk_fixed_put (GTK_FIXED (fixed8), label167, 16, 220);
  gtk_widget_set_size_request (label167, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label167), TRUE);

  label168 = gtk_label_new (_("wp"));
  gtk_widget_show (label168);
  gtk_fixed_put (GTK_FIXED (fixed8), label168, 16, 240);
  gtk_widget_set_size_request (label168, 41, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label168), TRUE);

  label178 = gtk_label_new (_("Flags"));
  gtk_widget_show (label178);
  gtk_fixed_put (GTK_FIXED (fixed8), label178, 16, 280);
  gtk_widget_set_size_request (label178, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label178), TRUE);

  label176 = gtk_label_new (_("BogoMIPS"));
  gtk_widget_show (label176);
  gtk_fixed_put (GTK_FIXED (fixed8), label176, 16, 260);
  gtk_widget_set_size_request (label176, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label176), TRUE);

  label159 = gtk_label_new (_("Model"));
  gtk_widget_show (label159);
  gtk_fixed_put (GTK_FIXED (fixed8), label159, 16, 80);
  gtk_widget_set_size_request (label159, 90, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label159), TRUE);

  label186 = gtk_label_new (_("Processor"));
  gtk_widget_show (label186);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (nb_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (nb_main), 0), label186);

  fixed9 = gtk_fixed_new ();
  gtk_widget_show (fixed9);
  gtk_container_add (GTK_CONTAINER (nb_main), fixed9);

  frame2 = gtk_frame_new (NULL);
  gtk_widget_show (frame2);
  gtk_fixed_put (GTK_FIXED (fixed9), frame2, 296, 144);
  gtk_widget_set_size_request (frame2, 168, 112);

  fixed10 = gtk_fixed_new ();
  gtk_widget_show (fixed10);
  gtk_container_add (GTK_CONTAINER (frame2), fixed10);

  pb_mem = gtk_progress_bar_new ();
  gtk_widget_show (pb_mem);
  gtk_fixed_put (GTK_FIXED (fixed10), pb_mem, 8, 16);
  gtk_widget_set_size_request (pb_mem, 150, 20);
  gtk_progress_bar_set_text (GTK_PROGRESS_BAR (pb_mem), _("Memory Use"));

  pb_swap = gtk_progress_bar_new ();
  gtk_widget_show (pb_swap);
  gtk_fixed_put (GTK_FIXED (fixed10), pb_swap, 8, 56);
  gtk_widget_set_size_request (pb_swap, 150, 20);
  gtk_progress_bar_set_text (GTK_PROGRESS_BAR (pb_swap), _("Swap Use"));

  label187 = gtk_label_new ("");
  gtk_widget_show (label187);
  gtk_frame_set_label_widget (GTK_FRAME (frame2), label187);

  image5 = create_pixmap (window1, "lkmonitor/gnome-ccperiph.png");
  gtk_widget_show (image5);
  gtk_fixed_put (GTK_FIXED (fixed9), image5, 400, 32);
  gtk_widget_set_size_request (image5, 48, 48);

  lbl_total = gtk_label_new ("");
  gtk_widget_show (lbl_total);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_total, 150, 40);
  gtk_widget_set_size_request (lbl_total, 80, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_total), TRUE);

  lbl_free = gtk_label_new ("");
  gtk_widget_show (lbl_free);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_free, 150, 60);
  gtk_widget_set_size_request (lbl_free, 80, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_free), TRUE);

  lbl_buffers = gtk_label_new ("");
  gtk_widget_show (lbl_buffers);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_buffers, 150, 80);
  gtk_widget_set_size_request (lbl_buffers, 88, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_buffers), TRUE);

  lbl_cached = gtk_label_new ("");
  gtk_widget_show (lbl_cached);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_cached, 150, 100);
  gtk_widget_set_size_request (lbl_cached, 88, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_cached), TRUE);

  lbl_active = gtk_label_new ("");
  gtk_widget_show (lbl_active);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_active, 150, 140);
  gtk_widget_set_size_request (lbl_active, 64, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_active), TRUE);

  lbl_inactive = gtk_label_new ("");
  gtk_widget_show (lbl_inactive);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_inactive, 150, 160);
  gtk_widget_set_size_request (lbl_inactive, 88, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_inactive), TRUE);

  lbl_dirty = gtk_label_new ("");
  gtk_widget_show (lbl_dirty);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_dirty, 150, 180);
  gtk_widget_set_size_request (lbl_dirty, 96, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_dirty), TRUE);

  lbl_hp_free = gtk_label_new ("");
  gtk_widget_show (lbl_hp_free);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_hp_free, 150, 220);
  gtk_widget_set_size_request (lbl_hp_free, 88, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_hp_free), TRUE);

  lbl_hp_size = gtk_label_new ("");
  gtk_widget_show (lbl_hp_size);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_hp_size, 150, 240);
  gtk_widget_set_size_request (lbl_hp_size, 96, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_hp_size), TRUE);

  lbl_high_total = gtk_label_new ("");
  gtk_widget_show (lbl_high_total);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_high_total, 150, 260);
  gtk_widget_set_size_request (lbl_high_total, 96, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_high_total), TRUE);

  lbl_high_free = gtk_label_new ("");
  gtk_widget_show (lbl_high_free);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_high_free, 150, 280);
  gtk_widget_set_size_request (lbl_high_free, 104, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_high_free), TRUE);

  lbl_low_total = gtk_label_new ("");
  gtk_widget_show (lbl_low_total);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_low_total, 150, 300);
  gtk_widget_set_size_request (lbl_low_total, 104, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_low_total), TRUE);

  lbl_low_free = gtk_label_new ("");
  gtk_widget_show (lbl_low_free);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_low_free, 150, 320);
  gtk_widget_set_size_request (lbl_low_free, 104, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_low_free), TRUE);

  lbl_swap_total = gtk_label_new ("");
  gtk_widget_show (lbl_swap_total);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_swap_total, 150, 340);
  gtk_widget_set_size_request (lbl_swap_total, 104, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_swap_total), TRUE);

  lbl_swap_free = gtk_label_new ("");
  gtk_widget_show (lbl_swap_free);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_swap_free, 150, 360);
  gtk_widget_set_size_request (lbl_swap_free, 88, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_swap_free), TRUE);

  label220 = gtk_label_new (_("Total"));
  gtk_widget_show (label220);
  gtk_fixed_put (GTK_FIXED (fixed9), label220, 16, 40);
  gtk_widget_set_size_request (label220, 60, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label220), TRUE);

  label218 = gtk_label_new (_("Free"));
  gtk_widget_show (label218);
  gtk_fixed_put (GTK_FIXED (fixed9), label218, 16, 60);
  gtk_widget_set_size_request (label218, 60, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label218), TRUE);

  label188 = gtk_label_new (_("Buffers"));
  gtk_widget_show (label188);
  gtk_fixed_put (GTK_FIXED (fixed9), label188, 16, 80);
  gtk_widget_set_size_request (label188, 60, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label188), TRUE);

  label189 = gtk_label_new (_("Cached"));
  gtk_widget_show (label189);
  gtk_fixed_put (GTK_FIXED (fixed9), label189, 16, 100);
  gtk_widget_set_size_request (label189, 60, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label189), TRUE);

  label190 = gtk_label_new (_("Swap cached"));
  gtk_widget_show (label190);
  gtk_fixed_put (GTK_FIXED (fixed9), label190, 16, 120);
  gtk_widget_set_size_request (label190, 100, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label190), TRUE);

  lbl_swap_cached = gtk_label_new ("");
  gtk_widget_show (lbl_swap_cached);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_swap_cached, 150, 120);
  gtk_widget_set_size_request (lbl_swap_cached, 88, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_swap_cached), TRUE);

  label191 = gtk_label_new (_("Active"));
  gtk_widget_show (label191);
  gtk_fixed_put (GTK_FIXED (fixed9), label191, 16, 140);
  gtk_widget_set_size_request (label191, 60, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label191), TRUE);

  label192 = gtk_label_new (_("Inactive"));
  gtk_widget_show (label192);
  gtk_fixed_put (GTK_FIXED (fixed9), label192, 16, 160);
  gtk_widget_set_size_request (label192, 100, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label192), TRUE);

  label193 = gtk_label_new (_("Dirty"));
  gtk_widget_show (label193);
  gtk_fixed_put (GTK_FIXED (fixed9), label193, 16, 180);
  gtk_widget_set_size_request (label193, 100, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label193), TRUE);

  lbl_hp_total = gtk_label_new ("");
  gtk_widget_show (lbl_hp_total);
  gtk_fixed_put (GTK_FIXED (fixed9), lbl_hp_total, 150, 200);
  gtk_widget_set_size_request (lbl_hp_total, 88, 16);
  gtk_label_set_line_wrap (GTK_LABEL (lbl_hp_total), TRUE);

  label194 = gtk_label_new (_("HugePages Total"));
  gtk_widget_show (label194);
  gtk_fixed_put (GTK_FIXED (fixed9), label194, 16, 200);
  gtk_widget_set_size_request (label194, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label194), TRUE);

  label195 = gtk_label_new (_("HugePages Free"));
  gtk_widget_show (label195);
  gtk_fixed_put (GTK_FIXED (fixed9), label195, 16, 220);
  gtk_widget_set_size_request (label195, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label195), TRUE);

  label196 = gtk_label_new (_("Huge Page size"));
  gtk_widget_show (label196);
  gtk_fixed_put (GTK_FIXED (fixed9), label196, 16, 240);
  gtk_widget_set_size_request (label196, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label196), TRUE);

  label211 = gtk_label_new (_("High total"));
  gtk_widget_show (label211);
  gtk_fixed_put (GTK_FIXED (fixed9), label211, 16, 260);
  gtk_widget_set_size_request (label211, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label211), TRUE);

  label197 = gtk_label_new (_("High free"));
  gtk_widget_show (label197);
  gtk_fixed_put (GTK_FIXED (fixed9), label197, 16, 280);
  gtk_widget_set_size_request (label197, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label197), TRUE);

  label198 = gtk_label_new (_("Low total"));
  gtk_widget_show (label198);
  gtk_fixed_put (GTK_FIXED (fixed9), label198, 16, 300);
  gtk_widget_set_size_request (label198, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label198), TRUE);

  label199 = gtk_label_new (_("Low free"));
  gtk_widget_show (label199);
  gtk_fixed_put (GTK_FIXED (fixed9), label199, 16, 320);
  gtk_widget_set_size_request (label199, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label199), TRUE);

  label200 = gtk_label_new (_("Swap total"));
  gtk_widget_show (label200);
  gtk_fixed_put (GTK_FIXED (fixed9), label200, 16, 340);
  gtk_widget_set_size_request (label200, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label200), TRUE);

  label201 = gtk_label_new (_("Swap free"));
  gtk_widget_show (label201);
  gtk_fixed_put (GTK_FIXED (fixed9), label201, 16, 360);
  gtk_widget_set_size_request (label201, 120, 16);
  gtk_label_set_line_wrap (GTK_LABEL (label201), TRUE);

  label222 = gtk_label_new (_("Memory"));
  gtk_widget_show (label222);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (nb_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (nb_main), 1), label222);

  g_signal_connect ((gpointer) window1, "destroy",
                    G_CALLBACK (on_window1_destroy),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window1, window1, "window1");
  GLADE_HOOKUP_OBJECT (window1, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (window1, menubar1, "menubar1");
  GLADE_HOOKUP_OBJECT (window1, menubar1_uiinfo[0].widget, "menuitem3");
  GLADE_HOOKUP_OBJECT (window1, menu3_uiinfo[0].widget, "imagemenuitem3");
  GLADE_HOOKUP_OBJECT (window1, menubar1_uiinfo[1].widget, "menuitem4");
  GLADE_HOOKUP_OBJECT (window1, menu4_uiinfo[0].widget, "imagemenuitem4");
  GLADE_HOOKUP_OBJECT (window1, nb_main, "nb_main");
  GLADE_HOOKUP_OBJECT (window1, fixed8, "fixed8");
  GLADE_HOOKUP_OBJECT (window1, image4, "image4");
  GLADE_HOOKUP_OBJECT (window1, lbl_processor, "lbl_processor");
  GLADE_HOOKUP_OBJECT (window1, lbl_vendor, "lbl_vendor");
  GLADE_HOOKUP_OBJECT (window1, lbl_family, "lbl_family");
  GLADE_HOOKUP_OBJECT (window1, lbl_model, "lbl_model");
  GLADE_HOOKUP_OBJECT (window1, lbl_stepping, "lbl_stepping");
  GLADE_HOOKUP_OBJECT (window1, lbl_Mhz, "lbl_Mhz");
  GLADE_HOOKUP_OBJECT (window1, lbl_cache, "lbl_cache");
  GLADE_HOOKUP_OBJECT (window1, lbl_fpu, "lbl_fpu");
  GLADE_HOOKUP_OBJECT (window1, lbl_fpu_exception, "lbl_fpu_exception");
  GLADE_HOOKUP_OBJECT (window1, lbl_cpu_id_level, "lbl_cpu_id_level");
  GLADE_HOOKUP_OBJECT (window1, lbl_wp, "lbl_wp");
  GLADE_HOOKUP_OBJECT (window1, lbl_bogomips, "lbl_bogomips");
  GLADE_HOOKUP_OBJECT (window1, scrolledwindow2, "scrolledwindow2");
  GLADE_HOOKUP_OBJECT (window1, viewport2, "viewport2");
  GLADE_HOOKUP_OBJECT (window1, lbl_flags, "lbl_flags");
  GLADE_HOOKUP_OBJECT (window1, label183, "label183");
  GLADE_HOOKUP_OBJECT (window1, label184, "label184");
  GLADE_HOOKUP_OBJECT (window1, label158, "label158");
  GLADE_HOOKUP_OBJECT (window1, lbl_model_name, "lbl_model_name");
  GLADE_HOOKUP_OBJECT (window1, label162, "label162");
  GLADE_HOOKUP_OBJECT (window1, label160, "label160");
  GLADE_HOOKUP_OBJECT (window1, label163, "label163");
  GLADE_HOOKUP_OBJECT (window1, label164, "label164");
  GLADE_HOOKUP_OBJECT (window1, label165, "label165");
  GLADE_HOOKUP_OBJECT (window1, label166, "label166");
  GLADE_HOOKUP_OBJECT (window1, label167, "label167");
  GLADE_HOOKUP_OBJECT (window1, label168, "label168");
  GLADE_HOOKUP_OBJECT (window1, label178, "label178");
  GLADE_HOOKUP_OBJECT (window1, label176, "label176");
  GLADE_HOOKUP_OBJECT (window1, label159, "label159");
  GLADE_HOOKUP_OBJECT (window1, label186, "label186");
  GLADE_HOOKUP_OBJECT (window1, fixed9, "fixed9");
  GLADE_HOOKUP_OBJECT (window1, frame2, "frame2");
  GLADE_HOOKUP_OBJECT (window1, fixed10, "fixed10");
  GLADE_HOOKUP_OBJECT (window1, pb_mem, "pb_mem");
  GLADE_HOOKUP_OBJECT (window1, pb_swap, "pb_swap");
  GLADE_HOOKUP_OBJECT (window1, label187, "label187");
  GLADE_HOOKUP_OBJECT (window1, image5, "image5");
  GLADE_HOOKUP_OBJECT (window1, lbl_total, "lbl_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_free, "lbl_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_buffers, "lbl_buffers");
  GLADE_HOOKUP_OBJECT (window1, lbl_cached, "lbl_cached");
  GLADE_HOOKUP_OBJECT (window1, lbl_active, "lbl_active");
  GLADE_HOOKUP_OBJECT (window1, lbl_inactive, "lbl_inactive");
  GLADE_HOOKUP_OBJECT (window1, lbl_dirty, "lbl_dirty");
  GLADE_HOOKUP_OBJECT (window1, lbl_hp_free, "lbl_hp_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_hp_size, "lbl_hp_size");
  GLADE_HOOKUP_OBJECT (window1, lbl_high_total, "lbl_high_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_high_free, "lbl_high_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_low_total, "lbl_low_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_low_free, "lbl_low_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_swap_total, "lbl_swap_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_swap_free, "lbl_swap_free");
  GLADE_HOOKUP_OBJECT (window1, label220, "label220");
  GLADE_HOOKUP_OBJECT (window1, label218, "label218");
  GLADE_HOOKUP_OBJECT (window1, label188, "label188");
  GLADE_HOOKUP_OBJECT (window1, label189, "label189");
  GLADE_HOOKUP_OBJECT (window1, label190, "label190");
  GLADE_HOOKUP_OBJECT (window1, lbl_swap_cached, "lbl_swap_cached");
  GLADE_HOOKUP_OBJECT (window1, label191, "label191");
  GLADE_HOOKUP_OBJECT (window1, label192, "label192");
  GLADE_HOOKUP_OBJECT (window1, label193, "label193");
  GLADE_HOOKUP_OBJECT (window1, lbl_hp_total, "lbl_hp_total");
  GLADE_HOOKUP_OBJECT (window1, label194, "label194");
  GLADE_HOOKUP_OBJECT (window1, label195, "label195");
  GLADE_HOOKUP_OBJECT (window1, label196, "label196");
  GLADE_HOOKUP_OBJECT (window1, label211, "label211");
  GLADE_HOOKUP_OBJECT (window1, label197, "label197");
  GLADE_HOOKUP_OBJECT (window1, label198, "label198");
  GLADE_HOOKUP_OBJECT (window1, label199, "label199");
  GLADE_HOOKUP_OBJECT (window1, label200, "label200");
  GLADE_HOOKUP_OBJECT (window1, label201, "label201");
  GLADE_HOOKUP_OBJECT (window1, label222, "label222");

  return window1;
}

GtkWidget*
create_about (void)
{
  const gchar *authors[] = {
    "Founder and lead developer:",
    "Fernando Apesteguia <fernape@users.sourceforge.net>\n",
    "Developers:",
    "Jokin Segundo <daedalvs@users.sourceforge.net>\n",
    "Website:",
    "M. Luz Lopez <mlopmar@users.sourceforge.net> ",
    "Julio Tejedor <jtejpal@users.sourceforge.net>",
    NULL
  };
  const gchar *documenters[] = {
    "Fernando Apesteguia <fernape@users.sourceforge.net>",
    "Jokin Segundo <daedalvs@users.sourceforge.net>",
    "M. Luz Lopez <mlopmar@users.sourceforge.net> ",
    "Julio Tejedor <jtejpal@users.sourceforge.net>",
    NULL
  };
  /* TRANSLATORS: Replace this string with your names, one name per line. */
  gchar *translators = _("translator_credits");
  GdkPixbuf *about_logo_pixbuf;
  GtkWidget *about;
  GdkPixbuf *about_icon_pixbuf;

  if (!strcmp (translators, "translator_credits"))
    translators = NULL;
  about_logo_pixbuf = create_pixbuf ("lkmonitor/lkm-logo.png");
  about = gnome_about_new ("lkmonitor", VERSION,
                        _("Copyright (c) Fernando Apesteguia"),
                        _("Linux Kernel Monitor"),
                        authors,
                        documenters,
                        translators,
                        about_logo_pixbuf);
  gtk_container_set_border_width (GTK_CONTAINER (about), 5);
  about_icon_pixbuf = create_pixbuf ("lkmonitor/lkm-logo.png");
  if (about_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (about), about_icon_pixbuf);
      gdk_pixbuf_unref (about_icon_pixbuf);
    }
  gtk_window_set_type_hint (GTK_WINDOW (about), GDK_WINDOW_TYPE_HINT_DIALOG);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (about, about, "about");

  return about;
}
