/*
lkmonitor (Linux Kernel Monitor)

Application for monitoring and tuning a Linux kernel.

Copyright (C) 2005,2006  Fernando Apesteguía

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#include <stdio.h>
#include <string.h>
#include <dirent.h>
#include <sys/types.h>
#include <stdlib.h>
#include <glib.h>

#include "lininfo.h"
#include "others.h"

/*! Collects cpu information 
* \param cpu Structure to fill with collected information
* \return 0 if success
*/

int
get_cpu_info (struct cpu_info *cpu)
{
  gchar* contenido;
  char* str;
  
  if(g_file_get_contents(CPU_FILE,&contenido,NULL,NULL)==FALSE)
	  //Error accesing file. Stop program 
  	g_error("Can't read %s file",CPU_FILE);
  
  str=contenido;
  find_data_for("processor : %[^\n]",cpu->processor,str);
  find_data_for("vendor_id : %[^\n]",cpu->vendor_id,str);
  find_data_for("cpu family : %[^\n]",cpu->cpu_family,str);
  find_data_for("model : %[^\n]",cpu->model,str);
  find_data_for("model name : %[^\n]",cpu->model_name,str)	;
  find_data_for("stepping : %[^\n]",cpu->stepping,str);
  find_data_for("cpu MHz : %[^\n]",cpu->Mhz,str);
  find_data_for("cache size : %[^\n]",cpu->cache,str);
  find_data_for("fpu : %[^\n]",cpu->fpu,str);
  find_data_for("fpu_exception : %[^\n]",cpu->fpu_exception,str);
  find_data_for("cpuid level : %[^\n]",cpu->cpuid_level,str);
  find_data_for("wp : %[^\n]",cpu->wp,str);
  find_data_for("flags : %[^\n]",cpu->flags,str);
  find_data_for("bogomips : %[^\n]",cpu->bogomips,str);
	

  g_free(contenido);

  return (0);
}				///End get_cpu_info


/*! Collects memory information 
* \param mem Structure to fill with collected information
* \return 0 if success
*/

int
get_mem_info (struct mem_info *mem)
{
	gchar* contenido;
	
	if(g_file_get_contents(MEM_FILE,&contenido,NULL,NULL)==FALSE)
		//Can't read file. Stop program
		g_error("Can't read %s file",MEM_FILE);

  find_data_for ("MemTotal: %[^\n]",mem->total, contenido);
  find_data_for ("MemFree: %[^\n]",mem->free, contenido);
  find_data_for ("Buffers: %[^\n]",mem->buffers, contenido);
  find_data_for ("Cached: %[^\n]",mem->cached, contenido);
  find_data_for ("SwapCached: %[^\n]",mem->swap_cached, contenido);
  find_data_for ("Active: %[^\n]",mem->active, contenido);
  find_data_for ("Inactive: %[^\n]",mem->inactive,contenido);
  find_data_for ("Dirty: %[^\n]",mem->dirty, contenido);
  find_data_for ("HighTotal: %[^\n]",mem->high_total, contenido);
  find_data_for ("HighFree: %[^\n]",mem->high_free, contenido);
  find_data_for ("LowTotal: %[^\n]",mem->low_total, contenido);
  find_data_for ("LowFree: %[^\n]",mem->low_free, contenido);
  find_data_for ("SwapTotal: %[^\n]",mem->swap_total, contenido);
  find_data_for ("SwapFree: %[^\n]",mem->swap_free, contenido);
  find_data_for ("HugePages_Total: %[^\n]",mem->hugepages_total, contenido);
  find_data_for ("HugePages_Free: %[^\n]",mem->hugepages_free, contenido);
  find_data_for ("Hugepagesize: %[^\n]",mem->hugepages_size, contenido);

  g_free(contenido);
  
  return (0);
}				///End get_mem_info
