/*
lkmonitor (Linux Kernel Monitor)

Application for monitoring and tuning a Linux kernel.

Copyright (C) 2005,2006  Fernando Apesteguía

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#include <glib.h>


#define PROC_DIR  "/proc/"
#define CPU_FILE  "/proc/cpuinfo"
#define MEM_FILE  "/proc/meminfo"
#define MAX_FIELD_SZ  255
#define FIELD_SZ  10


/*! \struct cpu_info lininfo.h
*   \brief Contains cpu characteristics.
*  This struct contains several fields that represent different cpu
*  characteristics as clock MHz or cache size
*/
struct cpu_info
{
  char processor[FIELD_SZ];	///< Id of the processor
  char vendor_id[2 * FIELD_SZ];	///< Vendor Id
  char cpu_family[2 * FIELD_SZ];///< Cpu family (currently an integer number)
  char model[FIELD_SZ];		///Integer id. for the model
  char model_name[5 * FIELD_SZ];	///Vendor's name for the model
  char stepping[FIELD_SZ];///< Microprocessor's stepping
  char Mhz[FIELD_SZ];///< Cpu clock
  char cache[FIELD_SZ];///< Second level cache size
  char fpu[FIELD_SZ / 2];///< Float Point Unit
  char fpu_exception[FIELD_SZ / 2];///< Cpu uses specific fpu exception
  char cpuid_level[FIELD_SZ / 2];///< For SMP	
  char wp[FIELD_SZ / 2];
  char flags[50 * FIELD_SZ];///< Specific characteristics for this model
  char bogomips[FIELD_SZ];///< Speed unit used in Linux.
};

/*! \struct mem_info lininfo.h
*   \brief Contains memory data and statistics.
*   Contains fields for total, free and other interesting information
*/
struct mem_info
{
  char total[FIELD_SZ];	///< Total physical memory
  char free[FIELD_SZ];	///< Free memory
  char shared[FIELD_SZ]; ///< Shared
  char buffers[FIELD_SZ]; ///< Kb used for buffers
  char cached[FIELD_SZ];  ///< Kb cached
  char swap_cached[FIELD_SZ]; ///< Kb cached for swap memory
  char active[FIELD_SZ];  ///< Kb of active memory
  char inactive[FIELD_SZ]; ///< Kb of inactive memory
  char dirty[FIELD_SZ];  ///< Kb of dirty memory
  char high_total[FIELD_SZ];  ///< Total high memory
  char high_free[FIELD_SZ];  ///< Free memory 
  char low_total[FIELD_SZ];  ///< Total low memory 
  char low_free[FIELD_SZ];   ///< Free low memory
  char swap_total[FIELD_SZ]; ///< Kb of swap 
  char swap_free[FIELD_SZ];   ///< Kb free swap
  char hugepages_total[FIELD_SZ]; ///< Number of hugepage
  char hugepages_free[FIELD_SZ];  ///< Free hupages
  char hugepages_size[FIELD_SZ];  ///< Size of each hupage
};


void update_cpu ();		///< Refresh data in window widgets for cpu
void update_mem ();		///< Refresh data in window widgets for memory

int get_cpu_info ();		///< Fills cpu_info struct fields
int get_mem_info ();		///< Fills mem_struct fields
