/*
lkmonitor (Linux Kernel Monitor)

Application for monitoring and tuning a Linux kernel.

Copyright (C) 2005,2006  Fernando Apesteguía

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

///Update data functions
///Show updated data to user

#include <glib.h>

#include <gtk/gtk.h>
#include <signal.h>
#include "lininfo.h"
#include "support.h"
#include <string.h>
#include <stdio.h>
#include <stdlib.h>


extern GtkWidget *window1;
extern struct mem_info mem;
extern struct cpu_info cpu;

/*! Update gtk widgets for memory panel
* This function updates labels, progress bar and other widgets to show
* the most recent values.
* Before, it calls to get_mem_info to collect data
*/
void
update_mem ()
{

  GtkLabel *cosa;
  GtkProgressBar *progreso;
  gfloat total, free;

  get_mem_info (&mem);
	
  //Get Gtk thread lock
  gdk_threads_enter();

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_total");
  gtk_label_set_text (cosa, (gchar *) mem.total);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_free");
  gtk_label_set_text (cosa, (gchar *) mem.free);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_buffers");
  gtk_label_set_text (cosa, (gchar *) mem.buffers);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_cached");
  gtk_label_set_text (cosa, (gchar *) mem.cached);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_swap_cached");
  gtk_label_set_text (cosa, (gchar *) mem.swap_cached);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_active");
  gtk_label_set_text (cosa, (gchar *) mem.active);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_inactive");
  gtk_label_set_text (cosa, (gchar *) mem.inactive);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_dirty");
  gtk_label_set_text (cosa, (gchar *) mem.dirty);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_hp_total");
  gtk_label_set_text (cosa, (gchar *) mem.hugepages_total);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_hp_free");
  gtk_label_set_text (cosa, (gchar *) mem.hugepages_free);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_hp_size");
  gtk_label_set_text (cosa, (gchar *) mem.hugepages_size);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_high_total");
  gtk_label_set_text (cosa, (gchar *) mem.high_total);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_high_free");
  gtk_label_set_text (cosa, (gchar *) mem.high_free);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_low_total");
  gtk_label_set_text (cosa, (gchar *) mem.low_total);


  cosa = (GtkLabel *) lookup_widget (window1, "lbl_low_free");
  gtk_label_set_text (cosa, (gchar *) mem.low_free);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_swap_total");
  gtk_label_set_text (cosa, (gchar *) mem.swap_total);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_swap_free");
  gtk_label_set_text (cosa, (gchar *) mem.swap_free);

  //Compute percentage of memory use
  total = atoi (strtok (mem.total, " "));
  free = atoi (strtok (mem.free, " "));

  g_assert(total!=0);
  
  progreso = (GtkProgressBar *) (lookup_widget (window1, "pb_mem"));
  gtk_progress_bar_set_fraction (progreso, (gfloat) ((total - free) / total));


  //Compute percentage of swap use. Reuse variables.


  total = atoi (strtok (mem.swap_total, " "));
  free = atoi (strtok (mem.swap_free, " "));

  //g_assert(total!=0);
  
  progreso = (GtkProgressBar *) (lookup_widget (window1, "pb_swap"));
  
  if(total!=0)
    gtk_progress_bar_set_fraction (progreso, (gfloat) ((total - free) / total));
  else
    gtk_progress_bar_set_text(progreso, (gchar *)"Not present");
  
  gdk_threads_leave();
}				///En actualize_mem


/*! Update gtk widgets for cpu panel
* This function updates labels to show recent values.
* Before, it calls to get_cpu_info to collect data
*/
void
update_cpu ()
{

  get_cpu_info (&cpu);

  GtkLabel *cosa;

  /*This function is called only once, before collector thread is created.
  So, we don't need thread lock. Only one thread is accessing gtk widgets
  at a time.*/
	
  cosa = (GtkLabel *) lookup_widget (window1, "lbl_processor");
  gtk_label_set_text (cosa, (gchar *) cpu.processor);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_vendor");
  gtk_label_set_text (cosa, (gchar *) cpu.vendor_id);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_family");
  gtk_label_set_text (cosa, (gchar *) cpu.cpu_family);


  cosa = (GtkLabel *) lookup_widget (window1, "lbl_model");
  gtk_label_set_text (cosa, (gchar *) cpu.model);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_model_name");
  gtk_label_set_text (cosa, (gchar *) cpu.model_name);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_stepping");
  gtk_label_set_text (cosa, (gchar *) cpu.stepping);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_Mhz");
  gtk_label_set_text (cosa, (gchar *) cpu.Mhz);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_cache");
  gtk_label_set_text (cosa, (gchar *) cpu.cache);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_fpu");
  gtk_label_set_text (cosa, (gchar *) cpu.fpu);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_fpu_exception");
  gtk_label_set_text (cosa, (gchar *) cpu.fpu_exception);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_cpu_id_level");
  gtk_label_set_text (cosa, (gchar *) cpu.cpuid_level);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_wp");
  gtk_label_set_text (cosa, (gchar *) cpu.wp);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_bogomips");
  gtk_label_set_text (cosa, (gchar *) cpu.bogomips);

  cosa = (GtkLabel *) lookup_widget (window1, "lbl_flags");
  gtk_label_set_text (cosa, (gchar *) cpu.flags);

 
}
